@@ -1,12 +1,13 @@
 import logging
 from typing import Dict, Optional, Tuple
 
-from django.conf import settings
 from django.template import engines
 from django.utils.html import mark_safe  # type: ignore
 
 from markdown2 import markdown_path
 
+from .config.paths import get_content_directory
+from .config.settings import get_markdown_extras
 from .retriever import get_data
 
 
@@ -14,33 +15,22 @@ logger = logging.getLogger(__name__)
 
 DEFAULT_TEMPLATE = "coltrane/content.html"
 
-DEFAULT_MARKDOWN_EXTRAS = [
-    "fenced-code-blocks",
-    "header-ids",
-    "metadata",
-    "strike",
-    "tables",
-    "task_list",
-]
-
 
 def _get_markdown_content_as_html(slug: str) -> Dict[str, Optional[Dict]]:
     """
     Converts markdown file based on the slug into HTML.
     """
 
-    file_path = settings.BASE_DIR / "content" / f"{slug}.md"
-
-    markdown_extras = DEFAULT_MARKDOWN_EXTRAS
-
-    if hasattr(settings, "COLTRANE") and settings.COLTRANE.get("MARKDOWN_EXTRAS"):
-        markdown_extras = settings.COLTRANE["MARKDOWN_EXTRAS"]
+    file_path = get_content_directory() / f"{slug}.md"
+    markdown_extras = get_markdown_extras()
 
     content = markdown_path(
         file_path,
         extras=markdown_extras,
     )
 
+    # TODO: hasattr(content, "toc_html")
+
     return (str(content), content.metadata)
 
 
